from setuptools import setup, find_packages

setup(
    name='MyPackagevab',
    version='1.5.2',
    packages=find_packages(),
    long_description=open('README.md').read(),
    description='A package for generators, iterators, decorators, and descriptors',
    author='BychVA',
)
